:mod:`cf.sqlparse.dialects` -- This module contains classes that represent SQL dialects.
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: cf.sqlparse.dialects
   :members:
   :synopsis: This module contains classes that represent SQL dialects.
